/*
 * Project name:
     Stepper Click Board Example
 * Copyright:
     (c) Mikroelektronika, 2015.
 * Revision History:
     20140225:
       - initial release (FJ);
 * Description:
     This is a simple demonstration of the Stepper Click Board usage. Use PB7, PB6, PB5 and PB4 buttons
     to toggle stepper motor resolution. Use PB0 and PB1 arrow buttons to initiate CW or CCW motor rotations.
     You can monitor resolution and rotations on the Lcd.
 * Test configuration:
     MCU:             ATmega32
                      http://www.atmel.com/Images/doc2503.pdf
     Dev. Board:      EasyAVR7
                      http://www.mikroe.com/easyavr/
     Oscillator:      Oscillator Frequency 8.0000 MHz, 8.0000 MHz Crystal
     Ext. Modules:    Stepper Click Board - ac:Stepper_Click_Board
                      http://www.mikroe.com/click/stepper/
                      LCD 2x16 chars - ac:LCD
                      http://www.mikroe.com/store/components/displays/                     
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/mikroc/avr/
 * NOTES:
     - Place DC Motor click board at the mikroBUS socket 1 on the EasyAVR v7 board.
     - Bipolar stepper motor connections :
          OUT2A - Blue wire
          OUT1A - Pink wire
          OUT2B - Yellow wire
          OUT1B - Orange wire
          NC    - Red wire
     - Put MOTOR PWR jumper in 5V position.
     - Put power supply jumper (J5) on the EasyAVR7 board in 5V position.
     - Pull-down PORTB, Pull-up SW1.2 on the EasyAVR v7 board.
     - Put Lcd in its socket, turn on backlight using the SW3.1,
         and adjust contrast via P2 potentiometer on the EasyAVR v7 board.
  */

// Bipolar Stepper motor driver connections
sbit DIR  at PORTA5_bit;
sbit STEP at PORTD4_bit;
sbit MS1 at PORTA7_bit;
sbit MS2 at PORTA6_bit;

sbit DIR_Direction  at DDA5_bit;
sbit STEP_Direction at DDD4_bit;
sbit MS1_Direction at DDA7_bit;
sbit MS2_Direction at DDA6_bit;
// End Bipolar Stepper motor driver connections

// Lcd module connections
sbit LCD_RS at PORTA2_bit;
sbit LCD_EN at PORTD6_bit;
sbit LCD_D4 at PORTC4_bit;
sbit LCD_D5 at PORTC5_bit;
sbit LCD_D6 at PORTC6_bit;
sbit LCD_D7 at PORTC7_bit;

sbit LCD_RS_Direction at DDA2_bit;
sbit LCD_EN_Direction at DDD6_bit;
sbit LCD_D4_Direction at DDC4_bit;
sbit LCD_D5_Direction at DDC5_bit;
sbit LCD_D6_Direction at DDC6_bit;
sbit LCD_D7_Direction at DDC7_bit;
// End LCD module connections
  
unsigned int cnt = 0;

// Routine to execute single step
void Single_Step(){
  STEP = 0;
  Delay_ms(3);
  STEP = 1;
  Delay_ms(3);
}

void main() {
  // Set Bipolar Stepper motor driver direction
  DIR_Direction = 1;
  STEP_Direction = 1;
  MS1_Direction = 1;
  MS2_Direction = 1;

  // Default start-up configuration
  DIR = 0;                       // Set clockwise direction
  MS1 = 0;                       // Set full step
  MS2 = 0;

  Lcd_Init();                    // Init LCD
  Lcd_Cmd(_LCD_CLEAR);           // Clear display
  Lcd_Cmd(_LCD_CURSOR_OFF);      // Cursor off
  
  // Intro message
  Lcd_Out(1, 1, "Set res. PD7-PD4");
  Lcd_Out(2, 1, "Set rot. PD0,PD1");
  Delay_ms(3000);
  Lcd_Cmd(_LCD_CLEAR);
  
  Lcd_Out(1, 1, "Res:  Full Step");
  Lcd_Out(2, 1, "Rotation: ");

  while (1) {
    // Full Step
    if (Button(&PINB, 7, 1, 1)) {
      MS1 = 0;
      MS2 = 0;
      Lcd_Out(1, 7, "Full Step");
    }

    // 1/2 Step
    if (Button(&PINB, 6, 1, 1)) {
      MS1 = 1;
      MS2 = 0;
      Lcd_Out(1, 7, "1/2 Step ");
    }

    // 1/4 Step
    if (Button(&PINB, 5, 1, 1)) {
      MS1 = 0;
      MS2 = 1;
      Lcd_Out(1, 7, "1/4 Step ");
    }
    
    // 1/8 Step
    if (Button(&PINB, 4, 1, 1)) {
      MS1 = 1;
      MS2 = 1;
      Lcd_Out(1, 7, "1/8 Step ");
    }

    // Rotate clockwise
    if (Button(&PINB, 1, 1, 1)) {
      DIR = 0;                   // Set clockwise direction
      Lcd_Out(2, 13, "CW");      // Display message on Lcd
      
      // Rotate 360 degrees
      for (cnt = 0; cnt <= 2038; cnt++) {
        Single_Step();                  // Make single step
        if (Button(&PINB, 0, 5, 1)) {  // Change rotation direction to counterclockwise
          break;
        }
      }
    }

    // Rotate counterclockwise
    if (Button(&PINB, 0, 1, 1)){
      DIR = 1;                   // Set counterclockwise direction
      Lcd_Out(2, 12, "CCW");     // Display message on Lcd
      
      // Rotate 360 degrees
      for (cnt = 0; cnt <= 2038; cnt++) {
        Single_Step();                  // Make single step
        if (Button(&PINB, 1, 5, 1))    // Change rotation direction to clockwise
          break;
      }
      Lcd_Chr(2, 12, ' ');
    }
  }
}